TapApplePayFlutter class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- setupApplePay → Future
-
no setter
Static Methods
-
buildApplePayButton(
{required ApplePayButtonType applePayButtonType, required ApplePayButtonStyle applePayButtonStyle, required dynamic onPress()?}) → Widget -
getApplePayToken(
{required ApplePayConfig config}) → Future -
getTapToken(
{required ApplePayConfig config}) → Future -
setupApplePayConfiguration(
{required String sandboxKey, required String productionKey, required SdkMode sdkMode, required String? merchantId, int applePayButtonRadius = 0}) → void - App configurations